==> framework_2.7.tar.gz: java/bioLegato.0.7.0/src/Core/test/org/biolegato/core/data/sequence/SequenceTest.java <==
/*
 * SequenceTest.java
 * JUnit based test
 *
 * Created on March 15, 2010, 2:50 PM
 */

package org.biolegato.core.data.sequence;

import java.util.HashMap;
import junit.framework.*;
import java.util.LinkedList;

/**
 *
 * @author alvare
 */
public class SequenceTest extends TestCase {
    
    public SequenceTest(String testName) {
	super(testName);
    }

    @Override
    protected void setUp() throws Exception {
    }

    @Override
    protected void tearDown() throws Exception {
    }

    public static class TypeTest extends TestCase {

	    public TypeTest(String testName) {
		    super(testName);
	    }

	    protected void setUp() throws Exception {
	    }

	    protected void tearDown() throws Exception {
	    }

	    public static Test suite() {
		    TestSuite suite = new TestSuite(TypeTest.class);

		    return suite;
	    }
    }


    public static class DirectionTest extends TestCase {

	    public DirectionTest(String testName) {
		    super(testName);
	    }

	    protected void setUp() throws Exception {
	    }

	    protected void tearDown() throws Exception {
	    }

	    public static Test suite() {
		    TestSuite suite = new TestSuite(DirectionTest.class);

		    return suite;
	    }
    }


    public static class TopologyTest extends TestCase {

	    public TopologyTest(String testName) {
		    super(testName);
	    }

	    protected void setUp() throws Exception {
	    }

	    protected void tearDown() throws Exception {
	    }

	    public static Test suite() {
		    TestSuite suite = new TestSuite(TopologyTest.class);

		    return suite;
	    }
    }


    public static class StrandednessTest extends TestCase {

	    public StrandednessTest(String testName) {
		    super(testName);
	    }

	    protected void setUp() throws Exception {
	    }

	    protected void tearDown() throws Exception {
	    }

	    public static Test suite() {
		    TestSuite suite = new TestSuite(StrandednessTest.class);

		    return suite;
	    }
    }


    public static class CharacterClassTest extends TestCase {

	    public CharacterClassTest(String testName) {
		    super(testName);
	    }

	    protected void setUp() throws Exception {
	    }

	    protected void tearDown() throws Exception {
	    }

	    public static Test suite() {
		    TestSuite suite = new TestSuite(CharacterClassTest.class);

		    return suite;
	    }
    }


    public static Test suite() {
	    TestSuite suite = new TestSuite(SequenceTest.class);

	    return suite;
    }

    /**
     * Test of addListener method, of class org.biolegato.core.data.sequence.Sequence.
     */
    public void testAddListener() {
	    System.out.println("addListener");

	    SequenceListener listener = null;
	    Sequence instance = new Sequence();

	    instance.addListener(listener);

	    // TODO review the generated test code and remove the default call to fail.
	    fail("The test case is a prototype.");
    }

    /**
     * Test of removeListener method, of class org.biolegato.core.data.sequence.Sequence.
     */
    public void testRemoveListener() {
	    System.out.println("removeListener");

	    SequenceListener listener = null;
	    Sequence instance = new Sequence();

	    instance.removeListener(listener);

	    // TODO review the generated test code and remove the default call to fail.
	    fail("The test case is a prototype.");
    }

    /**
     * Test of get method, of class org.biolegato.core.data.sequence.Sequence.
     */
    public void testGet() {
	final HashMap<String, Object> values = new HashMap<String, Object>();
	
	System.out.println("get");

	Object key = null;
	Sequence instance = new Sequence();

	Object expResult = null;
	Object result = instance.get(key);
	assertEquals(expResult, result);

	// TODO review the generated test code and remove the default call to fail.
	fail("The test case is a prototype.");
    }

    /**
     * Test of modified variable, of class org.biolegato.core.data.sequence.Sequence.
     */
    public void testModified() {
	final HashMap<String, Object> values = new HashMap<String, Object>();
	
	System.out.println("get");

	Object key = null;
	Sequence instance = new Sequence();

	Object expResult = null;
	Object result = instance.get(key);
	assertEquals(expResult, result);

	// TODO review the generated test code and remove the default call to fail.
	fail("The test case is a prototype.");
    }
    
    /**
     * Test of put method, of class org.biolegato.core.data.sequence.Sequence.
     */
    public void testPut() {
	    System.out.println("put");

	    String key = "";
	    Object value = null;
	    Sequence instance = new Sequence();

	    Object expResult = null;
	    Object result = instance.put(key, value);
	    assertEquals(expResult, result);

	    // TODO review the generated test code and remove the default call to fail.
	    fail("The test case is a prototype.");
    }

    /**
     * Test of insertField method, of class org.biolegato.core.data.sequence.Sequence.
     */
    public void testInsertField() {
	    System.out.println("insertField");

	    String field = "";
	    int column = 0;
	    String string = "";
	    Sequence instance = new Sequence();

	    boolean expResult = true;
	    boolean result = instance.insertField(field, column, string);
	    assertEquals(expResult, result);

	    // TODO review the generated test code and remove the default call to fail.
	    fail("The test case is a prototype.");
    }

    /**
     * Test of getDefault method, of class org.biolegato.core.data.sequence.Sequence.
     */
    public void testDefaults() {
	System.out.println("getDefault");

	String key = "";

	Object expResult = null;
	Object result = Sequence.getDefault(key);
	assertEquals(expResult, result);

	// TODO review the generated test code and remove the default call to fail.
	fail("The test case is a prototype.");
    }

    /**
     * Test of toString method, of class org.biolegato.core.data.sequence.Sequence.
     */
    public void testToString() {
	    System.out.println("toString");

	    Sequence instance = new Sequence();

	    String expResult = "";
	    String result = instance.toString();
	    assertEquals(expResult, result);

	    // TODO review the generated test code and remove the default call to fail.
	    fail("The test case is a prototype.");
    }

    /**
     * Test of clone method, of class org.biolegato.core.data.sequence.Sequence.
     */
    public void testClone() {
	    System.out.println("clone");

	    Sequence instance = new Sequence();

	    Object expResult = null;
	    Object result = instance.clone();
	    assertEquals(expResult, result);

	    // TODO review the generated test code and remove the default call to fail.
	    fail("The test case is a prototype.");
    }

    /**
     * Test of charType method, of class org.biolegato.core.data.sequence.Sequence.
     */
    public void testCharType() {
	System.out.println("charType");

	char test = ' ';
	Sequence instance = new Sequence();

	Sequence.CharacterClass expResult = null;
	Sequence.CharacterClass result = instance.charType(test);
	assertEquals(expResult, result);

	// TODO review the generated test code and remove the default call to fail.
	fail("The test case is a prototype.");
    }

    /**
     * Test of group method, of class org.biolegato.core.data.sequence.Sequence.
     */
    public void testGrouping() {
	System.out.println("group");

	Integer groupNumber = null;
	Sequence[] sequences = null;
	LinkedList<Sequence> expResult = null;
	LinkedList<Sequence> result = Sequence.getgroup(groupNumber);

	Sequence.group(sequences);

	// TODO review the generated test code and remove the default call to fail.
	fail("The test case is a prototype.");
	System.out.println("ungroup");

	Sequence.ungroup(sequences);

	// TODO review the generated test code and remove the default call to fail.
	fail("The test case is a prototype.");
	System.out.println("getgroup");

	assertEquals(expResult, result);

	// TODO review the generated test code and remove the default call to fail.
	fail("The test case is a prototype.");
    }
}

==> framework_2.8.tar.gz: java/bioLegato.0.7.3/src/Core/test/org/biolegato/core/data/sequence/SequenceTest.java <==
/*
 * SequenceTest.java
 * JUnit based test
 *
 * Created on March 15, 2010, 2:50 PM
 */

package org.biolegato.core.data.sequence;

import java.util.HashMap;
import java.util.List;
import junit.framework.*;
import java.util.LinkedList;
import org.biolegato.gdesupport.canvas.data.Cell;
import org.biolegato.gdesupport.canvas.data.CellListener;

/**
 *
 * @author alvare
 */
public class SequenceTest extends TestCase {
    
    public SequenceTest(String testName) {
	super(testName);
    }

    @Override
    protected void setUp() throws Exception {
    }

    @Override
    protected void tearDown() throws Exception {
    }

    public static class TypeTest extends TestCase {

	    public TypeTest(String testName) {
		    super(testName);
	    }

	    protected void setUp() throws Exception {
	    }

	    protected void tearDown() throws Exception {
	    }

	    public static Test suite() {
		    TestSuite suite = new TestSuite(TypeTest.class);

		    return suite;
	    }
    }


    public static class DirectionTest extends TestCase {

	    public DirectionTest(String testName) {
		    super(testName);
	    }

	    protected void setUp() throws Exception {
	    }

	    protected void tearDown() throws Exception {
	    }

	    public static Test suite() {
		    TestSuite suite = new TestSuite(DirectionTest.class);

		    return suite;
	    }
    }


    public static class TopologyTest extends TestCase {

	    public TopologyTest(String testName) {
		    super(testName);
	    }

	    protected void setUp() throws Exception {
	    }

	    protected void tearDown() throws Exception {
	    }

	    public static Test suite() {
		    TestSuite suite = new TestSuite(TopologyTest.class);

		    return suite;
	    }
    }


    public static class StrandednessTest extends TestCase {

	    public StrandednessTest(String testName) {
		    super(testName);
	    }

	    protected void setUp() throws Exception {
	    }

	    protected void tearDown() throws Exception {
	    }

	    public static Test suite() {
		    TestSuite suite = new TestSuite(StrandednessTest.class);

		    return suite;
	    }
    }


    public static class CharacterClassTest extends TestCase {

	    public CharacterClassTest(String testName) {
		    super(testName);
	    }

	    protected void setUp() throws Exception {
	    }

	    protected void tearDown() throws Exception {
	    }

	    public static Test suite() {
		    TestSuite suite = new TestSuite(CharacterClassTest.class);

		    return suite;
	    }
    }


    public static Test suite() {
	    TestSuite suite = new TestSuite(SequenceTest.class);

	    return suite;
    }

    /**
     * Test of addListener method, of class org.biolegato.core.data.sequence.Cell.
     */
    public void testAddListener() {
	    System.out.println("addListener");

	    CellListener listener = null;
	    Cell instance = new Cell();

	    instance.addListener(listener);

	    // TODO review the generated test code and remove the default call to fail.
	    fail("The test case is a prototype.");
    }

    /**
     * Test of removeListener method, of class org.biolegato.core.data.sequence.Cell.
     */
    public void testRemoveListener() {
	    System.out.println("removeListener");

	    CellListener listener = null;
	    Cell instance = new Cell();

	    instance.removeListener(listener);

	    // TODO review the generated test code and remove the default call to fail.
	    fail("The test case is a prototype.");
    }

    /**
     * Test of get method, of class org.biolegato.core.data.sequence.Cell.
     */
    public void testGet() {
	final HashMap<String, Object> values = new HashMap<String, Object>();
	
	System.out.println("get");

	Object key = null;
	Cell instance = new Cell();

	Object expResult = null;
	Object result = instance.get(key);
	assertEquals(expResult, result);

	// TODO review the generated test code and remove the default call to fail.
	fail("The test case is a prototype.");
    }

    /**
     * Test of modified variable, of class org.biolegato.core.data.sequence.Cell.
     */
    public void testModified() {
	final HashMap<String, Object> values = new HashMap<String, Object>();
	
	System.out.println("get");

	Object key = null;
	Cell instance = new Cell();

	Object expResult = null;
	Object result = instance.get(key);
	assertEquals(expResult, result);

	// TODO review the generated test code and remove the default call to fail.
	fail("The test case is a prototype.");
    }
    
    /**
     * Test of put method, of class org.biolegato.core.data.sequence.Cell.
     */
    public void testPut() {
	    System.out.println("put");

	    String key = "";
	    Object value = null;
	    Cell instance = new Cell();

	    Object expResult = null;
	    Object result = instance.put(key, value);
	    assertEquals(expResult, result);

	    // TODO review the generated test code and remove the default call to fail.
	    fail("The test case is a prototype.");
    }

    /**
     * Test of insertField method, of class org.biolegato.core.data.sequence.Cell.
     */
    public void testInsertField() {
	    System.out.println("insertField");

	    String field = "";
	    int column = 0;
	    String string = "";
	    Cell instance = new Cell();

	    boolean expResult = true;
	    boolean result = instance.insertField(field, column, string);
	    assertEquals(expResult, result);

	    // TODO review the generated test code and remove the default call to fail.
	    fail("The test case is a prototype.");
    }

    /**
     * Test of getDefault method, of class org.biolegato.core.data.sequence.Cell.
     */
    public void testDefaults() {
	System.out.println("getDefault");

	String key = "";

	Object expResult = null;
	Object result = Cell.getDefault(key);
	assertEquals(expResult, result);

	// TODO review the generated test code and remove the default call to fail.
	fail("The test case is a prototype.");
    }

    /**
     * Test of toString method, of class org.biolegato.core.data.sequence.Cell.
     */
    public void testToString() {
	    System.out.println("toString");

	    Cell instance = new Cell();

	    String expResult = "";
	    String result = instance.toString();
	    assertEquals(expResult, result);

	    // TODO review the generated test code and remove the default call to fail.
	    fail("The test case is a prototype.");
    }

    /**
     * Test of clone method, of class org.biolegato.core.data.sequence.Cell.
     */
    public void testClone() {
	    System.out.println("clone");

	    Cell instance = new Cell();

	    Object expResult = null;
	    Object result = instance.clone();
	    assertEquals(expResult, result);

	    // TODO review the generated test code and remove the default call to fail.
	    fail("The test case is a prototype.");
    }

    /**
     * Test of charType method, of class org.biolegato.core.data.sequence.Cell.
     */
    public void testCharType() {
	System.out.println("charType");

	char test = ' ';
	Cell instance = new Cell();

	Cell.CharacterClass expResult = null;
	Cell.CharacterClass result = instance.charType(test);
	assertEquals(expResult, result);

	// TODO review the generated test code and remove the default call to fail.
	fail("The test case is a prototype.");
    }

    /**
     * Test of group method, of class org.biolegato.core.data.sequence.Cell.
     */
    public void testGrouping() {
	System.out.println("group");

	Integer groupNumber = null;
	Cell[] sequences = null;
	List<Cell> expResult = null;
	List<Cell> result = Cell.getgroup(groupNumber);

	datamodel.group(sequences);

	// TODO review the generated test code and remove the default call to fail.
	fail("The test case is a prototype.");
	System.out.println("ungroup");

	Cell.ungroup(sequences);

	// TODO review the generated test code and remove the default call to fail.
	fail("The test case is a prototype.");
	System.out.println("getgroup");

	assertEquals(expResult, result);

	// TODO review the generated test code and remove the default call to fail.
	fail("The test case is a prototype.");
    }
}
